## Read in data 
FinalDaph=read.csv("ConstanceFinalDaphniaSummary.csv"); 

require(gplots); 
require(grDevices); require(graphics)
panelLabel=function(text) mtext(text,side=3,adj=0,cex=1.25,line=0.1); 

graphics.off(); 

##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
## Plotting Juvenile Growth Rate 
##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
nlog=function(x) (x)
se=function(x) sd(x)/sqrt(length(x)-1)

JB <- FinalDaph[FinalDaph$Period=="Before",]; 
JB.mean=c(mean(nlog(JB$JGRgood)),mean(nlog(JB$JGRbad))); 
JB.se=c(se(nlog(JB$JGRgood)),se(nlog(JB$JGRbad))); 

JA <- FinalDaph[FinalDaph$Period=="After",]; 
JA.mean=c(mean(nlog(JA$JGRgood)),mean(nlog(JA$JGRbad))); 
JA.se=c(se(nlog(JA$JGRgood)),se(nlog(JA$JGRbad))); 

dev.new(width=9,height=4); 
par(xaxt="n",cex.axis=1.35,cex.lab=1.35,mar=c(4,5,2,1),mfrow=c(1,2)); 

plotCI(x=c(1.1,1.9),y=JB.mean,liw=JB.se,uiw=JB.se,type="b",lty=1,pch=1,
        ylim=c(0.23,0.47),xlab="",ylab="Juvenile Growth Rate (1/d)",xlim=c(1,2),lwd=2,cex=1.65);

par(new=TRUE); 

plotCI(x=c(1.1,1.9),y=JA.mean,liw=JA.se,uiw=JA.se,type="b",lty=1,pch=2,col="red",
ylim=c(0.23,0.47),xlab="",ylab="Juvenile Growth Rate (1/d)",xlim=c(1,2),lwd=2,cex=1.65);
par(xaxt="s"); 
axis(side=1,at=c(1.1,1.9),labels=c("Good Food","Poor Food"));

legend("topright",legend=c("Before (1962-71)","After (1992-97)"),
       pch=c(1,2),col=c(1,2),lty=1,bty="n",pt.cex=1.5,lwd=2,cex=1.25); 

h=(JB.mean[1]+JA.mean[2])/2; 
points(c(1.1,1.9),c(h,h),type="l",lty=2,lwd=2,col="blue"); 
panelLabel("(a)"); 

##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
## Plotting Adult Body Size
##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
AB <- FinalDaph[FinalDaph$Period=="Before",]; 
AB.mean=c(mean(nlog(AB$AWgood)),mean(nlog(AB$AWbad))); 
AB.se=c(se(nlog(AB$AWgood)),se(nlog(AB$AWbad))); 

AA <- FinalDaph[FinalDaph$Period=="After",]; 
AA.mean=c(mean(nlog(AA$AWgood)),mean(nlog(AA$AWbad))); 
AA.se=c(se(nlog(AA$AWgood)),se(nlog(AA$AWbad))); 

ECO=((AB.mean[1]+AA.mean[1])-(AB.mean[2]+AA.mean[2]))/2; 
EVO=mean(AA.mean)-mean(AB.mean); 
cat(EVO/ECO);

par(xaxt="n"); 
plotCI(x=c(1.1,1.9),y=AB.mean,liw=AB.se,uiw=AB.se,type="b",lty=1,pch=1,lwd=2,
	ylim=c(0.015,0.035), xlab="",ylab="Adult Size (mg)",xlim=c(1,2),cex=1.65);

par(new=TRUE); 
plotCI(x=c(1.12,1.92),y=AA.mean,liw=AA.se,uiw=AA.se,type="b",lty=1,pch=2,col="red",lwd=2,
ylim=c(0.015,0.035),xlab="",ylab="Adult Size (mg)",xlim=c(1,2),cex=1.65);
par(xaxt="s"); 
axis(side=1,at=c(1.1,1.9),labels=c("Good Food","Poor Food"));

panelLabel("(b)"); 

######################################################
# Plotting adult body size model
######################################################
x <- seq(-1, 0, length = 10)
y <- seq(0,1,length=10)
Asizefun <- function(x,y){-1.377 + 0.753*x + 0.13*y}
z <- outer(x, y, Asizefun)

dev.new(height=7,width=7)
par(cex.axis=1,cex.lab=1.4,yaxt="n",mar=c(0,4,0,2)); 
pmat=persp(x, y, z, theta = 20, phi = 20, expand = 0.5, col = "gray80",
      ltheta = 120, shade = 0.175, ticktype = "detailed",zlim=c(-2.5,-1),
      xlab = "Log10 Juv Growth Rate", ylab = "Food Quality", 
	zlab = "Log10 Adult Weight (mg)")


Before=FinalDaph[FinalDaph$Period=="Before",]; 
points(trans3d(x=log10(Before$JGRgood),y=rep(0.9,nrow(Before)),
z=log10(Before$AWgood), pmat = pmat), col = "black", pch =1,lwd=2,cex=1.5)

points(trans3d(x=log10(Before$JGRbad),y=rep(0.1,nrow(Before)),
z=log10(Before$AWbad), pmat = pmat), col = "black", pch =1,lwd=2,cex=1.5)


During=FinalDaph[FinalDaph$Period=="During",]; 
points(trans3d(x=log10(During$JGRgood),y=rep(0.9,nrow(During)),
z=log10(During$AWgood), pmat = pmat), col = "blue", pch =5,lwd=2,cex=1.3)

points(trans3d(x=log10(During$JGRbad),y=rep(0.1,nrow(During)),
z=log10(During$AWbad), pmat = pmat), col = "blue", pch =5,lwd=2,cex=1.3)


After=FinalDaph[FinalDaph$Period=="After",]; 
points(trans3d(x=log10(After$JGRgood),y=rep(0.9,nrow(After)),
z=log10(After$AWgood), pmat = pmat), col = "red", pch =2,lwd=2,cex=1.3)

points(trans3d(x=log10(After$JGRbad),y=rep(0.1,nrow(After)),
z=log10(After$AWbad), pmat = pmat), col = "red", pch =2,lwd=2,cex=1.3)

legend(x=0.01,y=-0.12,legend=c("Before", "During", "After"), 
pch=c(1,5,2), col=c("black","blue","red"),cex=1.5,bty="n",pt.lwd=2); 


